This crate contains kube-rs compatible bindings for Kubernetes custom resources for the digitalis.io group. Each binding is generated with kopium, updated and released weekly.
digitalis.io
ValsSecret
DbSecret